==> pegasus-merchandise-api-3.18-GS-20250605.073313-3-sources.jar: com/thebeastshop/pegasus/merchandise/vo/KnowledgeKeywordVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class KnowledgeKeywordVO implements Serializable {
    private Integer id;

    private String keyword;

    private Integer createId;

    private String createMan;

    private Date createTime;

    private Date updateTime;

    private Integer isDeleted;


    private List<KnowledgePlatformVO> platformVOs;


    private List<KnowledgeProductCodeVO> productCodeVOs;


    private List<KnowledgeProductVO> productVOs;
    private List<KnowledgeImgVO> imgVOs;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getKeyword() {
        return keyword;
    }

    public void setKeyword(String keyword) {
        this.keyword = keyword == null ? null : keyword.trim();
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan == null ? null : createMan.trim();
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public List<KnowledgePlatformVO> getPlatformVOs() {
        return platformVOs;
    }

    public void setPlatformVOs(List<KnowledgePlatformVO> platformVOs) {
        this.platformVOs = platformVOs;
    }

    public List<KnowledgeProductCodeVO> getProductCodeVOs() {
        return productCodeVOs;
    }

    public void setProductCodeVOs(List<KnowledgeProductCodeVO> productCodeVOs) {
        this.productCodeVOs = productCodeVOs;
    }

    public List<KnowledgeProductVO> getProductVOs() {
        return productVOs;
    }

    public void setProductVOs(List<KnowledgeProductVO> productVOs) {
        this.productVOs = productVOs;
    }

    public List<KnowledgeImgVO> getImgVOs() {
        return imgVOs;
    }

    public void setImgVOs(List<KnowledgeImgVO> imgVOs) {
        this.imgVOs = imgVOs;
    }
}

==> pegasus-merchandise-api-4.0.1-GS-20250625.053946-1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/KnowledgeKeywordVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class KnowledgeKeywordVO implements Serializable {
    private Integer id;

    private String keyword;

    private Integer createId;

    private String createMan;

    private Date createTime;

    private Date updateTime;

    private Integer isDeleted;
    private Integer type;

    private List<KnowledgePlatformVO> platformVOs;


    private List<KnowledgeProductCodeVO> productCodeVOs;


    private List<KnowledgeProductVO> productVOs;
    private List<KnowledgeImgVO> imgVOs;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getKeyword() {
        return keyword;
    }

    public void setKeyword(String keyword) {
        this.keyword = keyword == null ? null : keyword.trim();
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan == null ? null : createMan.trim();
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public List<KnowledgePlatformVO> getPlatformVOs() {
        return platformVOs;
    }

    public void setPlatformVOs(List<KnowledgePlatformVO> platformVOs) {
        this.platformVOs = platformVOs;
    }

    public List<KnowledgeProductCodeVO> getProductCodeVOs() {
        return productCodeVOs;
    }

    public void setProductCodeVOs(List<KnowledgeProductCodeVO> productCodeVOs) {
        this.productCodeVOs = productCodeVOs;
    }

    public List<KnowledgeProductVO> getProductVOs() {
        return productVOs;
    }

    public void setProductVOs(List<KnowledgeProductVO> productVOs) {
        this.productVOs = productVOs;
    }

    public List<KnowledgeImgVO> getImgVOs() {
        return imgVOs;
    }

    public void setImgVOs(List<KnowledgeImgVO> imgVOs) {
        this.imgVOs = imgVOs;
    }
}
